==> hoteldruid-mod-bg_2.2.0-1.zip: bg/crearegole.php <==
<?php

switch ($messaggio) {

case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Въведете зададените правила за резервациите за година"; break;
case "Regola di assegnazione":  		$messaggio = "Зададено правило"; break;
case "nel periodo dal":  			$messaggio = "в периода от"; break;
case "al":  					$messaggio = "до"; break;
case "motivazione":  				$messaggio = "мотивация"; break;
case "Inserisci la regola":  			$messaggio = "Въведете правило"; break;
case "Inserisci o modifica la regola":  	$messaggio = "Въведете или променете правило"; break;
case "Cancella tutte le regole di questo tipo":	$messaggio = "Изтрийте всички правила от този тип"; break;
case "Quando si sceglie la tariffa":  		$messaggio = "Когато избирате тарифа"; break;
case "se non si inserisce nessun altro metodo di assegnazione":	$messaggio = "ако не е въведен друг метод за задаване"; break;
case "Vedi le regole già inserite":  		$messaggio = "Вижте вече въведените правила"; break;
case "Torna al menù principale":  		$messaggio = "обратно в главното меню"; break;
case "Non sono stati inseriti tutti i dati necessari":	$messaggio = "Не са въведени всички необходими данни"; break;
case "Le date sono sbagliate":  		$messaggio = "Датите са грешни"; break;
case "opzionale":  				$messaggio = "опционлано"; break;
case "La regola è stata inserita":  		$messaggio = "Правилото е въведено"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":	$messaggio = "Сигурни ли сте, че искате да изтриете всички правила от тип 1"; break;
case "SI":  					$messaggio = "ДА"; break;
case "Le regole sono state cancellate":  	$messaggio = "Правилата са изтрити"; break;
case "Si deve scegliere la tariffa":  		$messaggio = "Трябва да изберете тарифата"; break;
case " non esiste":  				$messaggio = " не същуствува"; break;
case "La regola di assegnazione":		$messaggio = "Зададеното правило"; break;
case "è stata inserita":			$messaggio = "е въведено"; break;
case "è stata modificata":			$messaggio = "е променено"; break;
case "Torna indietro":  			$messaggio = "Обратно"; break;
case "Motivazione non valida":  		$messaggio = "Невалидна мотивация"; break;
case "La tariffa scelta ha già un utente associato, cancella la regola prima di inserirne una nuova":	$messaggio = "Избраната тарифа вече има зададен потребител, изтрийте правилото преди да въведете новото"; break;
case "Quando l'utente amministratore":  	$messaggio = "Когато административния потребител"; break;
case "sceglie la tariffa":  			$messaggio = "избере тарифа"; break;
case "fai risultare come se l'utente":  	$messaggio = "покажете все едно потребител"; break;
case "avesse inserito la prenotazione e l'eventuale cliente":	$messaggio = "е въвел резервацията и евентуалния клиент"; break;
case "Si deve inserire l'utente da associare":	$messaggio = "Трябва да въведете потребителят, който трябва да бъде асоцииран"; break;
case "L'utente ":  				$messaggio = "Потребителят "; break;
case "assegna automaticamente come numero di persone":	$messaggio = "автоматично назначавай като брой души"; break;
case "se non si inserisce nessun altro numero":	$messaggio = "ако не е въведен друг номер"; break;
case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":	$messaggio = "Избраната тарифа вече има зададен брой хора, изтрийте правилото преди да въведете ново"; break;
case "Si deve inserire il numero di persone da associare":	$messaggio = "Трябва да изберете брой хора за които се отнася"; break;
case "Eccezioni alla regola":  			$messaggio = "Exceptions to rule"; break;
case "e mancano meno di":  			$messaggio = " and less than"; break;
case "giorni":					$messaggio = "days are missing"; break;
case "dall'inizio":				$messaggio = "from the beginning"; break;
case "dalla fine":				$messaggio = "from the ending"; break;
case "della prenotazione quando essa viene inserita, allora":	$messaggio = "of the reservation when it is inserted, then"; break;
case "Inserisci o modifica questa eccezione alla regola":	$messaggio = "Insert or modify this exception to rule"; break;
case "Si deve inserire il numero di giorni":  	$messaggio = "The number of days must be inserted"; break;
case "Chiedi prima di assegnare":		$messaggio = "Ask before assigning"; break;
case "Chiudi":  				$messaggio = "Close"; break;
case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "The closed period has been freed of reservations"; break;
case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">It was not possible</span> to free from reservations the closed period"; break;
case "per le tariffe":  			$messaggio = "for rates"; break;
case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "A rule of this kind already exists for the selected period"; break;
case "assegna automaticamente":  		$messaggio = "automatically assign"; break;
case "tra":  					$messaggio = "between"; break;
case "da assegnare troppo alto, supera quello presente nella lista":	$messaggio = "to be assigned too high, exceeds the number in the list"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-bg_3.0.8-1.zip: bg/crearegole.php <==
<?php

switch ($messaggio) {

case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Въведете зададените правила за резервациите за година"; break;
case "Regola di assegnazione":  		$messaggio = "Зададено правило"; break;
case "nel periodo dal":  			$messaggio = "в периода от"; break;
case "al":  					$messaggio = "до"; break;
case "motivazione":  				$messaggio = "мотивация"; break;
case "Inserisci la regola":  			$messaggio = "Въведете правило"; break;
case "Inserisci o modifica la regola":  	$messaggio = "Въведете или променете правило"; break;
case "Cancella tutte le regole di questo tipo":	$messaggio = "Изтрийте всички правила от този тип"; break;
case "Quando si sceglie la tariffa":  		$messaggio = "Когато избирате тарифа"; break;
case "se non si inserisce nessun altro metodo di assegnazione":	$messaggio = "ако не е въведен друг метод за задаване"; break;
case "Vedi le regole già inserite":  		$messaggio = "Вижте вече въведените правила"; break;
case "Torna al menù principale":  		$messaggio = "обратно в главното меню"; break;
case "Non sono stati inseriti tutti i dati necessari":	$messaggio = "Не са въведени всички необходими данни"; break;
case "Le date sono sbagliate":  		$messaggio = "Датите са грешни"; break;
case "opzionale":  				$messaggio = "опционлано"; break;
case "La regola è stata inserita":  		$messaggio = "Правилото е въведено"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":	$messaggio = "Сигурни ли сте, че искате да изтриете всички правила от тип 1"; break;
case "SI":  					$messaggio = "ДА"; break;
case "Le regole sono state cancellate":  	$messaggio = "Правилата са изтрити"; break;
case "Si deve scegliere la tariffa":  		$messaggio = "Трябва да изберете тарифата"; break;
case " non esiste":  				$messaggio = " не същуствува"; break;
case "La regola di assegnazione":		$messaggio = "Зададеното правило"; break;
case "è stata inserita":			$messaggio = "е въведено"; break;
case "è stata modificata":			$messaggio = "е променено"; break;
case "Torna indietro":  			$messaggio = "Обратно"; break;
case "Motivazione non valida":  		$messaggio = "Невалидна мотивация"; break;
case "La tariffa scelta ha già un utente associato, cancella la regola prima di inserirne una nuova":	$messaggio = "Избраната тарифа вече има зададен потребител, изтрийте правилото преди да въведете новото"; break;
case "Quando l'utente amministratore":  	$messaggio = "Когато административния потребител"; break;
case "sceglie la tariffa":  			$messaggio = "избере тарифа"; break;
case "fai risultare come se l'utente":  	$messaggio = "покажете все едно потребител"; break;
case "avesse inserito la prenotazione e l'eventuale cliente":	$messaggio = "е въвел резервацията и евентуалния клиент"; break;
case "Si deve inserire l'utente da associare":	$messaggio = "Трябва да въведете потребителят, който трябва да бъде асоцииран"; break;
case "L'utente ":  				$messaggio = "Потребителят "; break;
case "assegna automaticamente come numero di persone":	$messaggio = "автоматично назначавай като брой души"; break;
case "se non si inserisce nessun altro numero":	$messaggio = "ако не е въведен друг номер"; break;
case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":	$messaggio = "Избраната тарифа вече има зададен брой хора, изтрийте правилото преди да въведете ново"; break;
case "Si deve inserire il numero di persone da associare":	$messaggio = "Трябва да изберете брой хора за които се отнася"; break;
case "Crea Regole":  				$messaggio = "Create Rules"; break;
case "Eccezioni alla regola":  			$messaggio = "Exceptions to rule"; break;
case "e mancano meno di":  			$messaggio = " and less than"; break;
case "giorni":					$messaggio = "days are missing"; break;
case "dall'inizio":				$messaggio = "from the beginning"; break;
case "dalla fine":				$messaggio = "from the ending"; break;
case "della prenotazione quando essa viene inserita, allora":	$messaggio = "of the reservation when it is inserted, then"; break;
case "Inserisci o modifica questa eccezione alla regola":	$messaggio = "Insert or modify this exception to rule"; break;
case "Si deve inserire il numero di giorni":  	$messaggio = "The number of days must be inserted"; break;
case "Chiedi prima di assegnare":		$messaggio = "Ask before assigning"; break;
case "Chiudi":  				$messaggio = "Close"; break;
case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "The closed period has been freed of reservations"; break;
case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">It was not possible</span> to free from reservations the closed period"; break;
case "per le tariffe":  			$messaggio = "for rates"; break;
case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "A rule of this kind already exists for the selected period"; break;
case "assegna automaticamente":  		$messaggio = "automatically assign"; break;
case "tra":  					$messaggio = "between"; break;
case "da assegnare troppo alto, supera quello presente nella lista":	$messaggio = "to be assigned too high, exceeds the number in the list"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "della regola 2 mancanti nella eccezione alla regola":	$messaggio = "in rule 2 that are missing from the exception to the rule"; break;
case "nella regola 2 di questa tariffa che non possono ospitare":	$messaggio = "in the rule 2 for this rate that can't host"; break;
case "persone":  				$messaggio = "people"; break;
case "nella regola di assegnazione 2 di questa tariffa":	$messaggio = "in the assignment rule 2 for this rate"; break;
case "Regole esistenti":  			$messaggio = "Existing rules"; break;
case "Cancella o ridimensiona queste regole":  	$messaggio = "Delete or scale down these rules"; break;
case "Cancella":  				$messaggio = "Delete"; break;
case "Ridimensiona":  				$messaggio = "Scale down"; break;
case "Modifica la regola":  			$messaggio = "Modify rule"; break;
case "chiusure":  				$messaggio = "closures"; break;
case "numero di persone":  			$messaggio = "number of people"; break;
case "utente inserimento":  			$messaggio = "inserting user"; break;
case "non permettere l'inserimento di prenotazioni con meno di":	$messaggio = "do not allow inserting reservations with less than"; break;
case "Il numero di persone minimo":  		$messaggio = "The minimum number of people"; break;
case "è maggiore del numero di persone predefinito":	$messaggio = "is bigger then the default number of people"; break;
case "è stata cancellata":  			$messaggio = "has been deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
